/* ncmpc (Ncurses MPD Client)
 * (c) 2004-2010 The Music Player Daemon Project
 * Project homepage: http://musicpd.org
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef NCMPC_WINDOW_H
#define NCMPC_WINDOW_H

#include "config.h"
#include "ncmpc_curses.h"

struct window {
	WINDOW *w;
	unsigned rows, cols;
};

static inline void
window_init(struct window *window, unsigned height, unsigned width,
	    int y, int x)
{
	window->w = newwin(height, width, y, x);
	window->cols = width;
	window->rows = height;
}

#endif
